#!/bin/bash

shellfu import pretty

#
# dist.sh module to query /etc/os-release
#

_distp_eor__get() {
    #
    # Get field from /etc/os-release
    #
    local key=$1
    case $key in
        id)         __distp_eor__rkey ID ;;
        name)       __distp_eor__rkey NAME ;;
        ver)        __distp_eor__rkey VERSION_ID | __distp_eor__takeN ;;
        cpe)        __distp_eor__rkey CPE_NAME ;;
        variant)    __distp_eor__rkey VARIANT ;;
        variant_id) __distp_eor__rkey VARIANT_ID ;;
        "")         mkusage -E KEY ;;
        *)          return 1
    esac
    return 0
}

__distp_eor__takeN() {
    #
    # Take any number of version fragments
    #
    grep -o -E '^[[:digit:]]+([.][[:digit:]]+)*'
}

_distp_eor__enum() {
    #
    # Enumerate known keys
    #
    echo id
    echo name
    echo ver
    echo cpe
    echo variant
    echo variant_id
}

__distp_eor__rkey() {
    #
    # Get field from /etc/os-release
    #
    local key=$1
    local code
    local eor=/etc/os-release
    test -f "$eor" || {
        warn "os-release file not found: $eor?"
        return 3
    }
    code=$(grep -m1 "^$key=" "$eor") || return 1
    bash -n <<<"$code" || {
        warn "syntax error in os-release file: '$code'"
        return 3
    }
    debug -v key
    debug -v code
    ( eval "$code; echo \$$key" ) | grep .
}

_distp_eor__sfpi_compat() {
    #
    # True if this plugin should work here
    #
    test -r /etc/os-release
}

#shellfu module-version=0.2.5
